﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Xml.Serialization;

namespace Reborn_Healer.IO
{
    /// <summary>
    /// Provides a way to load profiles from the disk.
    /// </summary>
    public class FileProfileLoader : IProfileLoader
    {
        public List<T> GetProfiles<T>() where T : Profile.Profile
        {
            // Get the profile directory and create it if it's needed
            var directory = Path.Combine(Environment.CurrentDirectory, "Profiles", typeof(T).Name);
            Directory.CreateDirectory(directory);

            // Fetch our profiles out
            var profiles = Directory.GetFiles(directory).Select(GetProfile<T>).ToList();
            return profiles;
        }

        public void SaveProfiles<T>(Profile.Profile profile) where T : Profile.Profile
        {
            var directory = Path.Combine(Environment.CurrentDirectory, "Profiles", typeof(T).Name);
            var filename = profile.Name + ProfileExtension;
            var path = Path.Combine(directory, filename);

            // Persists the actual profile to the disk
            PersistProfile<T>(path, profile);
        }

        public string ProfileExtension
        {
            get { return ".RBN"; }
        }

        /// <summary>
        /// Gets a specific profile from the disk, based on the file path that has been given.
        /// </summary>
        /// <typeparam name="T">The type of profile to retrieve</typeparam>
        /// <param name="path">The path to the profile we're going to load</param>
        /// <returns></returns>
        private T GetProfile<T>(string path) where T : Profile.Profile
        {
            var pSerializer = new XmlSerializer(typeof(T));
            T profile;
            using (var fs = File.Open(path, FileMode.Open))
                profile = (T)pSerializer.Deserialize(fs);
            return profile;
        }

        private void PersistProfile<T>(string path, Profile.Profile profile) where T : Profile.Profile
        {
            var pSerializer = new XmlSerializer(typeof(T));
            using (var fs = File.Open(path, FileMode.Create))
                pSerializer.Serialize(fs, profile);
        }
    }
}