﻿using Reborn_Healer.IO;
using System;
using System.Collections.Generic;

namespace Reborn_Healer.Managers
{
    /// <summary>
    /// A single profile manager that allows the
    /// </summary>
    public class ModeProfileManager
    {
        private IProfileLoader _loader;

        private static readonly Lazy<ModeProfileManager> lazy =
            new Lazy<ModeProfileManager>(() => new ModeProfileManager());

        public static ModeProfileManager Instance
        {
            get { return lazy.Value; }
        }

        /// <summary>
        /// Fetches a list of profiles of the given type.
        /// </summary>
        /// <typeparam name="T">The type of profiles to fetch; returns them all</typeparam>
        /// <returns></returns>
        public List<T> GetProfiles<T>() where T : Profile.Profile
        {
            return _loader.GetProfiles<T>();
        }

        /// <summary>
        /// Saves a given profile.
        /// </summary>
        /// <typeparam name="T">The type of the profile to save</typeparam>
        /// <param name="profile">The profile we want to save</param>
        public void SaveProfile<T>(Profile.Profile profile) where T : Profile.Profile
        {
            _loader.SaveProfiles<T>(profile);
        }

        /// <summary>
        /// Prevents outsides from creating
        /// </summary>
        private ModeProfileManager()
        {
            _loader = new FileProfileLoader();
        }
    }
}