﻿using Reborn_Healer.Tasks.Combat;

namespace Reborn_Healer.Profile.Combat
{
    /// <summary>
    /// An enumeration representing various levels of combat priority.
    /// It should be noted that these modes only work when the <see cref="Scope"/> is set to 'Ally'
    ///
    /// This property will be ignored when used with any other type of TargetScope.
    /// </summary>
    public enum CombatPriority
    {
        /// <summary>
        /// A tank <see cref="CombatPriority"/> will prioritize the tank in combat when using the <see cref="SkillGenerator"/>
        /// This will ignore everyone else who meets a given condition, and do them first and foremost.
        /// </summary>
        Tank,

        /// <summary>
        /// When this mode is selected, you will be prioritized over everyone else when using the <see cref="SkillGenerator"/>
        /// </summary>
        Yourself,

        /// <summary>
        /// When this mode is selected, no specific priority will be used. The built-in program AI will select who to heal.
        /// Usually, the <see cref="SkillGenerator"/> will decide to select the person with the lowest HP but this is not guarenteed.
        /// </summary>
        Other
    }
}