﻿using Reborn_Healer.Tasks;
using System;
using System.Collections.Generic;

namespace Reborn_Healer.Profile.Combat
{
    /// <summary>
    /// A combat profile that is consumed and used by the <see cref="CombatTask"/> to perform duties.
    /// </summary>
    public class CombatProfile : Profile
    {
        private List<SkillEntry> _entries = new List<SkillEntry>();

        /// <summary>
        /// Fetches the entry we want
        /// </summary>
        /// <param name="skillId"></param>
        /// <returns></returns>
        public void CreateSkillEntry(uint skillId)
        {
            var skillEntry = new SkillEntry(skillId);
            Entries.Add(skillEntry);
        }

        /// <summary>
        /// Fetches the entry we want based on user interaction.
        /// </summary>
        /// <param name="skillId"></param>
        /// <param name="index"></param>
        /// <returns></returns>
        public SkillEntry GetSkillEntry(uint skillId, int index)
        {
            for (int x = 0; x < Entries.Count; x++)
                if (Entries[index].SkillId == skillId)
                    return Entries[index];

            throw new Exception("Could not get skill entry. Did you select right index?");
        }

        /// <summary>
        /// Public information of current skillentrys in the combatprofile.
        /// </summary>
        public List<SkillEntry> Entries
        {
            get { return _entries; }
            set { _entries = value; }
        }

        /// <summary>
        ///
        /// </summary>
        public CombatPriority CombatPriority { get; set; }

        /// <summary>
        /// The name of this current combatprofile.
        /// </summary>
        /// <returns>Returns name of the combat profile.</returns>
        public override string ToString()
        {
            return Name;
        }

        /// <summary>
        /// Initializing constructor for this class with a name for it.
        /// </summary>
        /// <param name="name">Name of the combat profile.</param>
        public CombatProfile(string name)
        {
            Name = name;
        }

        /// <summary>
        /// Basic initializing constructor for combat profile.
        /// </summary>
        public CombatProfile()
        {
        }

        /// <summary>
        /// Move the spell position up or down in the list of your profile for different priority.
        /// </summary>
        /// <param name="upordown">Bool trigger to go up or down in position.</param>
        /// <param name="index">Pass in which skill was clicked to reposition itself from that current index.</param>
        /// <param name="skillId">The id of the skill.</param>
        /// <example>True = Up, False = Down</example>
        public void MoveSpellPosition(uint skillId, bool upordown, int index)
        {
            if (upordown)
            {
                #region Move skill entry up a posttion

                try
                {
                    if (index > 0)
                    {
                        var tempEntry = Entries[index];

                        for (int x = 0; x < Entries.Count; x++)
                            if (Entries[index].SkillId == skillId)
                            {
                                Entries[index] = Entries[(index - 1)];
                                Entries[(index - 1)] = tempEntry;
                            }
                    }
                }
                catch (Exception ex)
                {
                    throw new Exception("Sorry something went wrong.", ex);
                }

                #endregion Move skill entry up a posttion
            }
            else
            {
                #region Move skill entry down a posttion

                try
                {
                    if (index < Entries.Count - 1)
                    {
                        var tempEntry = Entries[index];

                        for (int x = 0; x < Entries.Count; x++)
                            if (Entries[index].SkillId == skillId)
                            {
                                Entries[index] = Entries[(index + 1)];
                                Entries[(index + 1)] = tempEntry;
                            }
                    }
                }
                catch (Exception ex)
                {
                    throw new Exception("Sorry something went wrong.", ex);
                }

                #endregion Move skill entry down a posttion
            }
        }

        /// <summary>
        /// Remove a skillentry from a combat profile based on index.
        /// </summary>
        /// <param name="skillId">SkillId of FFXIV skill.</param>
        /// <param name="index">The index where the current skill resides.</param>
        public void RemoveEntryByIdIndex(int index)
        {
            // Why not just that?
            Entries.RemoveAt(index);
        }
    }
}