﻿using ff14bot.Objects;
using Reborn_Healer.Tasks.Combat;
using System.Xml.Serialization;

namespace Reborn_Healer.Profile.Combat.Conditions
{
    /// <summary>
    /// A condition is tested for and evaluated for truth before a particular action can be executed.
    /// </summary>
    [XmlInclude(typeof(ValueCondition)),
    XmlInclude(typeof(BuffCondition))]
    public abstract class Condition
    {
        /// <summary>
        /// Evaluate if a given condition is true given the context
        /// </summary>
        /// <param name="context">The context we have been provided for the condition</param>
        /// <returns></returns>
        public abstract bool Evaluate(Character context);

        public abstract string Name { get; }

        /// <summary>
        /// The condition scope that will be applied to this condition.
        /// This is used to vary condition scoping.
        /// </summary>
        public Scope ConditionScope { get; set; }
    }
}