﻿using ff14bot.Objects;
using System;

namespace Reborn_Healer.Profile.Combat.Conditions
{
    /// <summary>
    /// A basic value condition that can contain several levels of thresholds on properties.
    /// </summary>

    public class ValueCondition : Condition
    {
        public enum ComparisonOperator
        {
            Equals,
            GreaterThan,
            LessThan
        }

        [ConditionDescription(typeof(ValueCondition))]
        public enum ValueOptions
        {
            CurrentHealthPercent,
            CurrentManaPercent,
            CurrentTP
        }

        /// <summary>
        /// The value we should evaluate to find
        /// </summary>
        public long Value { get; set; }

        public ComparisonOperator Operator { get; set; }

        public ValueOptions Property { get; set; }

        public override bool Evaluate(Character context)
        {
            var value = GetPropValue(context, Property.ToString());

            switch (Operator)
            {
                case ComparisonOperator.Equals:
                    return value == Value;

                case ComparisonOperator.GreaterThan:
                    return value > Value;

                case ComparisonOperator.LessThan:
                    return value < Value;
            }

            return true;
        }

        public override string Name
        {
            get { return Property + " " + Operator + " " + Value; }
        }

        /// <summary>
        /// Fetches a value from a property via reflection
        /// </summary>
        /// <returns></returns>
        private static long GetPropValue(Character source, string propName)
        {
            var test = (source.GetType().GetProperty(propName).GetValue(source, null));
            return Convert.ToInt64(test);
        }

        /// <summary>
        ///
        /// </summary>
        /// <param name="property">The property we're going to monitor</param>
        public ValueCondition(ValueOptions property)
        {
            Property = property;
        }

        public ValueCondition()
        {
        }
    }
}