﻿using ff14bot.Managers;
using ff14bot.Objects;
using System;
using System.Collections.Generic;
using System.Linq;

namespace Reborn_Healer.Tasks.Combat
{
    /// <summary>
    /// A scope generator will fetch the approriate scoping given
    /// </summary>
    public static class ScopeGenerator
    {
        /// <summary>
        /// Gets a battle BattleCharacter given an optional context which is required by some of the implementations.
        /// </summary>
        /// <param name="context">The context in which we apply this to. For example, a scope of Ally will point to context's allies.
        /// A context of an ally and scope of 'Pet' will return an evaluation of all allies pets.</param>
        /// <param name="scope"></param>
        /// <returns></returns>
        public static IEnumerable<Character> GetScopeBattleCharacter(BattleCharacter context, Scope scope)
        {
            var BattleCharacters = new List<Character>();

            switch (scope)
            {
                case Scope.Self:
                    BattleCharacters.Add(GetSelfBattleCharacters(context));
                    break;

                case Scope.Ally:
                    BattleCharacters = GetAllyBattleCharacters(context);
                    break;

                case Scope.Target:
                    BattleCharacters.Add(GetContextTarget(context));
                    break;

                default:
                    throw new NotImplementedException("This combo is not supported. Consider filing a bug report.");
            }

            return BattleCharacters;
        }

        private static Character GetContextTarget(BattleCharacter context)
        {
            //TODOO: This requires more thought and time to fix
            var temp = (LocalPlayer)context;

            if (temp.CurrentTarget == null || !(temp.CurrentTarget is Character))
                return null;

            return (Character)temp.CurrentTarget;
        }

        /// <summary>
        /// Returns yourself in relativity to the given context.
        /// </summary>
        /// <param name="context"></param>
        /// <returns></returns>
        private static Character GetSelfBattleCharacters(BattleCharacter context)
        {
            return context;
        }

        private static List<Character> GetAllyBattleCharacters(BattleCharacter context)
        {
            if (!context.IsMe)
                throw new NotSupportedException("Scoping against allys that are not your own is not supported.");

            // Get a list of party members allies
            var list = PartyManager.VisibleMembers.ToList();

            // Return a list of our allies
            var battleCharacters = list.Select(member => GameObjectManager.GetObjectsOfType<BattleCharacter>().First(x => x.ObjectId == member.ObjectId)).ToList();
            var characters = new List<Character>();

            foreach (var battleChar in battleCharacters)
                characters.Add(battleChar);

            return characters;
        }
    }
}