﻿using System;
using System.Threading;
using System.Threading.Tasks;

namespace Reborn_Healer.Tasks
{
    internal static class Threading
    {
        public static Task Interval(TimeSpan pollinterval, Action action, CancellationToken token)
        {
            // We don't use Observable.Interval:
            // If we block, the values start bunching up behind each other.
            return Task.Factory.StartNew(() =>
            {
                for (; ; )
                {
                    if (token.WaitCancellationRequested(pollinterval))
                        break;

                    action();
                }
            }, token, TaskCreationOptions.LongRunning, TaskScheduler.Default);
        }
    }
}

internal static class CancellationTokenExtensions
{
    public static bool WaitCancellationRequested(
        this CancellationToken token,
        TimeSpan timeout)
    {
        return token.WaitHandle.WaitOne(timeout);
    }
}