﻿using Reborn_Healer.Managers;
using Reborn_Healer.Profile.Combat;
using Reborn_Healer.Tasks;
using System;
using System.Collections.Generic;
using System.Windows.Forms;

namespace Reborn_Healer.UI.Combat
{
    public partial class CombatControl : UserControl
    {
        #region Variables
        #endregion Variables

        #region Accessors

        /// <summary>
        /// The combat task to be managed here
        /// </summary>
        public CombatTask CombatTask { get; set; }

        /// <summary>
        /// Curing list priority for combat task healing.
        /// </summary>
        public List<string> CurePriority { get; private set; }

        #endregion Accessors

        public CombatControl()
        {
            InitializeComponent();

            //Fetch all our current profiles that are saved.
            FetchProfiles();
        }

        /// <summary>
        /// Fetch and add our profiles into the combo box for plugin usage.
        /// </summary>
        public void FetchProfiles()
        {
            var tempProfileSelected = cbxProfileSelected.SelectedIndex;

            if (cbxProfileSelected.Items.Count > 0)
                cbxProfileSelected.Items.Clear();

            foreach (CombatProfile pf in ModeProfileManager.Instance.GetProfiles<CombatProfile>())
            {
                cbxProfileSelected.Items.Add(pf);
            }

            cbxProfileSelected.SelectedIndex = tempProfileSelected;
        }

        #region Event Handlers

        /// <summary>
        /// Triggers when user changes profiles and sets combat tasker to profile.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void cbxProfileSelected_SelectedIndexChanged(object sender, System.EventArgs e)
        {
            CombatTask.RunningProfile = (CombatProfile)cbxProfileSelected.SelectedItem;
        }

        /// <summary>
        /// Triggers when user changes bot mode and sets our combt tasker to this bot mode.
        /// </summary>
        /// <param name="sender">The control that changed.</param>
        /// <param name="e">The data the control holds.</param>
        private void cbxTaskSelect_SelectedIndexChanged(object sender, EventArgs e)
        {
            CombatTask.BotMode = ((ComboBox)sender).SelectedItem.ToString();
        }

        /// <summary>
        /// First priority healing combobox index changed.
        /// </summary>
        /// <param name="sender">The control that changed.</param>
        /// <param name="e">The data the control holds.</param>
        private void cbxPriority1_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (cbxPriority1 != null && cbxPriority1.SelectedItem != null)
            {
                if (CurePriority != null)
                {
                    if (CurePriority.Capacity > 0)
                        CurePriority.Clear();
                }
                else
                    CurePriority = new List<string>();

                //TODO:Let's check to see if any other combo box has this priority already selected.
                //If so then set other combobox selection to empty.

                CurePriority.Insert(0, cbxPriority1.SelectedText);
                cbxPriority2.Enabled = true;
            }
        }

        /// <summary>
        /// Second priority healing combobox index changed.
        /// </summary>
        /// <param name="sender">The control that changed.</param>
        /// <param name="e">The data the control holds.</param>
        private void cbxPriority2_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (cbxPriority2 != null && cbxPriority2.SelectedItem != null)
            {
                //TODO:Let's check to see if any other combo box has this priority already selected.
                //If so then set other combobox selection to empty.

                CurePriority.Insert(1, cbxPriority2.SelectedText);
                cbxPriority3.Enabled = true;
            }
        }

        /// <summary>
        /// Third priority healing combobox index changed.
        /// </summary>
        /// <param name="sender">The control that changed.</param>
        /// <param name="e">The data the control holds.</param>
        private void cbxPriority3_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (cbxPriority3 != null && cbxPriority3.SelectedItem != null)
            {
                //TODO:Let's check to see if any other combo box has this priority already selected.
                //If so then set other combobox selection to empty.

                CurePriority.Insert(2, cbxPriority3.SelectedText);
            }
        }

        #endregion Event Handlers
    }
}