﻿using ff14bot.Managers;
using Reborn_Healer.Profile.Combat;
using Reborn_Healer.Tasks;
using Reborn_Healer.UI.Combat;
using System;
using System.Threading;
using System.Windows.Forms;

namespace Reborn_Healer
{
    public partial class frmMain : Form
    {
        #region - Variables

        public static frmMain Instance { get; private set; }

        private CombatControl combatHost;
        private CombatTask task;
        private frmProfileManager ProfileManager;
        private CancellationTokenSource taskToken;
        private bool startStopBot;

        #endregion - Variables

        public frmMain()
        {
            Instance = this;

            InitializeComponent();

            SetupTaskHosts();
        }

        private void SetupTaskHosts()
        {
            combatHost = new CombatControl();
            task = new CombatTask();

            task.taskRunning += OnTaskCancel;
            combatHost.CombatTask = task;

            combatHost.Dock = DockStyle.Fill;

            pTaskHost.Controls.Add(combatHost);
        }

        /// <summary>
        /// Event Handler for when combat task fires off start/stop to itself.
        /// </summary>
        /// <param name="value"></param>
        private void OnTaskCancel(bool value)
        {
            startStopBot = value;

            if (value)
                tsslMain.Text = "Bot On";
            else
                tsslMain.Text = "Bot Off";
        }

        #region - Make sure our instance is alive and valid

        public static bool IsValid
        {
            get { return Instance != null && Instance.Visible && !Instance.Disposing && !Instance.IsDisposed; }
        }

        #endregion - Make sure our instance is alive and valid

        private void profileManagerToolStripMenuItem_Click(object sender, System.EventArgs e)
        {
            // Edit combat profiles
            ProfileManager = new frmProfileManager();
            ProfileManager.ShowAndBind<CombatProfile>();

            if (!ProfileManager.IsOpen)
            {
                combatHost.FetchProfiles();
            }
        }

        private void tsmiStartStop_Click(object sender, EventArgs e)
        {
            switch (task.IsAlive)
            {
                case true:
                    task.IsAlive = false;
                    break;

                case false:
                    if (task.RunningProfile != null || task.BotMode == null)
                    {
                        task.IsAlive = true;

                        if (taskToken == null)
                            taskToken = new CancellationTokenSource();

                        var taskThreader = Threading.Interval(TimeSpan.FromSeconds(1), () => task.Update(), taskToken.Token);
                    }
                    else
                    {
                        MessageBox.Show("No profile or botmode selected. Stopping bot.");
                    }
                    break;
            }
        }

        /// <summary>
        /// Shutting down form. Lets make sure things are disposed of before form totally closes.
        /// </summary>
        /// <param name="sender">The sender of this call.</param>
        /// <param name="e">Form closing event args.</param>
        private void frmMain_FormClosing(object sender, FormClosingEventArgs e)
        {
            this.task.IsAlive = false;
            if (taskToken != null)
                this.taskToken.Token.WaitCancellationRequested(TimeSpan.FromSeconds(1));
        }
    }
}